/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_9hYZ9lMZ);
  numBytes += sPhasor_k_init(&sPhasor_dYGKvw6g, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_bMo5ooP2);
  numBytes += sRPole_init(&sRPole_Ysp2A9CM);
  numBytes += sRPole_init(&sRPole_s7MF3JSI);
  numBytes += sTabhead_init(&sTabhead_LKipUpMb, &hTable_hNpVn8li);
  numBytes += sTabread_init(&sTabread_zLpWGFSR, &hTable_hNpVn8li, false);
  numBytes += sTabread_init(&sTabread_eYXQcAZU, &hTable_hNpVn8li, false);
  numBytes += sLine_init(&sLine_ZC8PsSy1);
  numBytes += sTabhead_init(&sTabhead_HAjrWnwX, &hTable_zzecy0BS);
  numBytes += sTabread_init(&sTabread_GgDpiDkR, &hTable_zzecy0BS, false);
  numBytes += sTabread_init(&sTabread_lGGye0c8, &hTable_zzecy0BS, false);
  numBytes += sLine_init(&sLine_whK7rgl3);
  numBytes += sTabwrite_init(&sTabwrite_GVu0bICL, &hTable_zzecy0BS);
  numBytes += sTabwrite_init(&sTabwrite_7q80D7mH, &hTable_hNpVn8li);
  numBytes += cVar_init_f(&cVar_rU8MfEc9, 0.0f);
  numBytes += cVar_init_f(&cVar_EnCoqboz, 0.0f);
  numBytes += cVar_init_f(&cVar_yCa3tXci, 0.0f);
  numBytes += cVar_init_f(&cVar_ys6rWo1R, 0.0f);
  numBytes += cVar_init_s(&cVar_ha7O3lRU, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_j3MCq2M3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bZ7Zsuen, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M7A7Rc4B, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_7TCtUYML, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_VNs1j8yc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5anhbECd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_u24ESYTh, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ra3MEDIS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gzXG5zxe, 0.0f);
  numBytes += hTable_init(&hTable_zzecy0BS, 256);
  numBytes += cDelay_init(this, &cDelay_kKjje1XX, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oNZvmqF8, 0.0f);
  numBytes += hTable_init(&hTable_hNpVn8li, 256);
  numBytes += cVar_init_f(&cVar_lPE74pv7, 14.0f);
  numBytes += cBinop_init(&cBinop_iW24JQnq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HRC1pyUC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WjfrG7x1, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4cABk9xO, 14.0f);
  numBytes += cBinop_init(&cBinop_TW921fw7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Dc5f07bK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_75SwsPQp, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_RBAmDpzb, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_7vtfBDpN, 1, -1);
  numBytes += cVar_init_f(&cVar_DH8VIBF6, 0.2f);
  numBytes += cSlice_init(&cSlice_BZrtO6pk, 1, -1);
  numBytes += cVar_init_f(&cVar_P9bkBk1M, 0.0f);
  numBytes += cSlice_init(&cSlice_AVSWdhIM, 1, -1);
  numBytes += cVar_init_f(&cVar_08RlrCHh, 2.0f);
  numBytes += cSlice_init(&cSlice_LYXAGvBl, 1, -1);
  numBytes += cVar_init_f(&cVar_JjwpjJLA, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_zzecy0BS);
  hTable_free(&hTable_hNpVn8li);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_zzecy0BS; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_hNpVn8li; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x7Y7cCby_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8GGn0NFt_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fCPhlmSf_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XtltbfWN_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kmvgeuds_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gn13ruHb_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHnLdsNb_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PPjM5siT_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0YZMhqjb_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_rU8MfEc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FUlsDDdQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_EnCoqboz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zt3ObWqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_yCa3tXci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n8CsP33k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_ys6rWo1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sKiXNQCz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_5KlwtKZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wQFipoqg_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_wQFipoqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_dYGKvw6g, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_zQFQZFGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9D5GgkPF_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_9D5GgkPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9Dv8bBOV_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_ha7O3lRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wtP3oI8t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_LlSv5iBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Kb1vaquR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_j3MCq2M3, m);
}

void Heavy_WSTD_FLANGR::cBinop_9Dv8bBOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bZ7Zsuen, m);
}

void Heavy_WSTD_FLANGR::cMsg_wtP3oI8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LlSv5iBT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Kb1vaquR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M7A7Rc4B, m);
}

void Heavy_WSTD_FLANGR::cMsg_FvGIiDbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FbDCEVga_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_FbDCEVga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nMwliOgp_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_7TCtUYML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ApVixOFu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_0vTQ7OIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1CrHTPIe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VNs1j8yc, m);
}

void Heavy_WSTD_FLANGR::cBinop_nMwliOgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5anhbECd, m);
}

void Heavy_WSTD_FLANGR::cMsg_ApVixOFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0vTQ7OIS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_1CrHTPIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_u24ESYTh, m);
}

void Heavy_WSTD_FLANGR::cBinop_LpVgBEdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6S4959bw_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_6S4959bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_358Eaeiv_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_gzdQStrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BqEwDa7I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_tjjAtuZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jaToUkG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_358Eaeiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_szW1STas_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_szW1STas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hwiI9U0g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gOM558Bs_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_gOM558Bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kAAb4e3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_hwiI9U0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EwJ4C0EV_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_EwJ4C0EV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_56EBWIWc_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_kAAb4e3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_A6xB2oqf_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_A6xB2oqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HMXzBRDF_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_56EBWIWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_gzdQStrA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_HMXzBRDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_tjjAtuZd_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_5TVBu2L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ugZ2tbkk_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ugZ2tbkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mYhWFqWO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_UwxDfsnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kOo9Im06_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_kOo9Im06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5r77kSOx_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_ra3MEDIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ra3MEDIS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gzXG5zxe, 0, m, &cDelay_gzXG5zxe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ra3MEDIS, 0, m, &cDelay_ra3MEDIS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVu0bICL, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_gzXG5zxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gzXG5zxe, m);
  cMsg_GIG6mLF2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_yAw6fAKt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_RSAeeFex_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_uVHiGDOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NfiehS2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_zzecy0BS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ifqhzkuI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ra3MEDIS, 2, m, &cDelay_ra3MEDIS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AF8PAOMD_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_NfiehS2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_zzecy0BS, 0, m, &hTable_zzecy0BS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_5r77kSOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_uVHiGDOn_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_GIG6mLF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_zzecy0BS, 0, m, &hTable_zzecy0BS_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_AF8PAOMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ra3MEDIS, 0, m, &cDelay_ra3MEDIS_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ifqhzkuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gzXG5zxe, 2, m, &cDelay_gzXG5zxe_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_RSAeeFex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVu0bICL, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_dirE9CGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dMWnAzmD_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_dMWnAzmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oy7IovJu_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_kKjje1XX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kKjje1XX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oNZvmqF8, 0, m, &cDelay_oNZvmqF8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kKjje1XX, 0, m, &cDelay_kKjje1XX_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7q80D7mH, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_oNZvmqF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oNZvmqF8, m);
  cMsg_PCyFcNV8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_2I1CUhQQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nfv3hqyc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_a5CZWxyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_krx5XaDr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_hNpVn8li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NaAG5vBQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kKjje1XX, 2, m, &cDelay_kKjje1XX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_syMWTAw8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_krx5XaDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_hNpVn8li, 0, m, &hTable_hNpVn8li_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_oy7IovJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_a5CZWxyP_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_PCyFcNV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_hNpVn8li, 0, m, &hTable_hNpVn8li_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_syMWTAw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kKjje1XX, 0, m, &cDelay_kKjje1XX_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_NaAG5vBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_oNZvmqF8, 2, m, &cDelay_oNZvmqF8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_nfv3hqyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_7q80D7mH, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_lPE74pv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iW24JQnq, HV_BINOP_MULTIPLY, 0, m, &cBinop_iW24JQnq_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_HaHLoerV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fLnHRTqd_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_fLnHRTqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ip3LD4a6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_iW24JQnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1aoysT2e_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_qxFG4p17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iW24JQnq, HV_BINOP_MULTIPLY, 1, m, &cBinop_iW24JQnq_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Ip3LD4a6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qxFG4p17_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_1aoysT2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_bImGvoNJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_bImGvoNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iEvFWzbG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WjfrG7x1, m);
}

void Heavy_WSTD_FLANGR::cBinop_iEvFWzbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HRC1pyUC, m);
}

void Heavy_WSTD_FLANGR::cVar_4cABk9xO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TW921fw7, HV_BINOP_MULTIPLY, 0, m, &cBinop_TW921fw7_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_IuRv6Hbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yEj49a02_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_yEj49a02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jDwAeE7P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_TW921fw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QeNDc5PZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Apjq2dUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TW921fw7, HV_BINOP_MULTIPLY, 1, m, &cBinop_TW921fw7_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_jDwAeE7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Apjq2dUz_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QeNDc5PZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_g2U5RBrJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_g2U5RBrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gJ1qgYl3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_75SwsPQp, m);
}

void Heavy_WSTD_FLANGR::cBinop_gJ1qgYl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Dc5f07bK, m);
}

void Heavy_WSTD_FLANGR::cMsg_mYhWFqWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bMo5ooP2, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_nVrw2pNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_tNj6AD1G_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_mdE5YA5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_nVrw2pNo_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_GpNObIvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_beRxF7dV_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_WNPXIcCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_J3JByscg_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_J3JByscg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RBAmDpzb, HV_BINOP_MULTIPLY, 1, m, &cBinop_RBAmDpzb_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_beRxF7dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_WNPXIcCl_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_RBAmDpzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cuzcTmY2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_tNj6AD1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RBAmDpzb, HV_BINOP_MULTIPLY, 0, m, &cBinop_RBAmDpzb_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_cuzcTmY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_whK7rgl3, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_Z5GrWJXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_fRzQeG9R_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_fRzQeG9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GpNObIvI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mdE5YA5e_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_OkseMblj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7vtfBDpN, 0, m, &cSlice_7vtfBDpN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hXyN6Gaj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_7vtfBDpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YLn4plNZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YLn4plNZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_DH8VIBF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YLn4plNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_YLn4plNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gn13ruHb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_hXyN6Gaj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BZrtO6pk, 0, m, &cSlice_BZrtO6pk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_x16ZI3Qw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_BZrtO6pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JjpJYeFh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JjpJYeFh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_P9bkBk1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JjpJYeFh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_JjpJYeFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kmvgeuds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_x16ZI3Qw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AVSWdhIM, 0, m, &cSlice_AVSWdhIM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PH42jgMa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_AVSWdhIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Gdxit1aF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Gdxit1aF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_08RlrCHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gdxit1aF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_Gdxit1aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PPjM5siT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_PH42jgMa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LYXAGvBl, 0, m, &cSlice_LYXAGvBl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_LYXAGvBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_E70Bmtpw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_E70Bmtpw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_JjwpjJLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_E70Bmtpw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_E70Bmtpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHnLdsNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_BqEwDa7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZC8PsSy1, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_jaToUkG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9hYZ9lMZ, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_sKiXNQCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OkseMblj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_FUlsDDdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OkseMblj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_zt3ObWqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OkseMblj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_n8CsP33k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OkseMblj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_HEftZWZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ys6rWo1R, 0, m, &cVar_ys6rWo1R_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yoCUp7Iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rU8MfEc9, 0, m, &cVar_rU8MfEc9_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_xEct8SIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yCa3tXci, 0, m, &cVar_yCa3tXci_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_PPjM5siT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_5KlwtKZl_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_kmvgeuds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Z5GrWJXF_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_0YZMhqjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HaHLoerV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lPE74pv7, 0, m, &cVar_lPE74pv7_sendMessage);
  cMsg_IuRv6Hbx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4cABk9xO, 0, m, &cVar_4cABk9xO_sendMessage);
  cMsg_UwxDfsnB_sendMessage(_c, 0, m);
  cMsg_dirE9CGx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DH8VIBF6, 0, m, &cVar_DH8VIBF6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P9bkBk1M, 0, m, &cVar_P9bkBk1M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_08RlrCHh, 0, m, &cVar_08RlrCHh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JjwpjJLA, 0, m, &cVar_JjwpjJLA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ha7O3lRU, 0, m, &cVar_ha7O3lRU_sendMessage);
  cMsg_zQFQZFGa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7TCtUYML, 0, m, &cVar_7TCtUYML_sendMessage);
  cMsg_FvGIiDbS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_bHnLdsNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LpVgBEdl_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_Gn13ruHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5TVBu2L1_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_XtltbfWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EnCoqboz, 0, m, &cVar_EnCoqboz_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_fCPhlmSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_HEftZWZV_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_8GGn0NFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_xEct8SIB_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_x7Y7cCby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yoCUp7Iz_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_9hYZ9lMZ, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_dYGKvw6g, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_bMo5ooP2, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_WjfrG7x1, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HRC1pyUC, VOf(Bf3));
    __hv_rpole_f(&sRPole_Ysp2A9CM, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_75SwsPQp, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Dc5f07bK, VOf(Bf4));
    __hv_rpole_f(&sRPole_s7MF3JSI, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_LKipUpMb, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_bZ7Zsuen, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_M7A7Rc4B, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_j3MCq2M3, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_zLpWGFSR, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_eYXQcAZU, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_ZC8PsSy1, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_HAjrWnwX, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_5anhbECd, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_u24ESYTh, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_VNs1j8yc, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_GgDpiDkR, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_lGGye0c8, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_whK7rgl3, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_GVu0bICL, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_7q80D7mH, VIf(Bf0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
