/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalPhasor.h"
#include "HvSignalTabread.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvSignalRPole.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvTable.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvSignalDel1.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_rU8MfEc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EnCoqboz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yCa3tXci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ys6rWo1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5KlwtKZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wQFipoqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zQFQZFGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9D5GgkPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ha7O3lRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LlSv5iBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Dv8bBOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wtP3oI8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kb1vaquR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FvGIiDbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FbDCEVga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7TCtUYML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0vTQ7OIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nMwliOgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ApVixOFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1CrHTPIe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LpVgBEdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6S4959bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gzdQStrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tjjAtuZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_358Eaeiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_szW1STas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gOM558Bs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hwiI9U0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EwJ4C0EV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kAAb4e3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A6xB2oqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_56EBWIWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HMXzBRDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5TVBu2L1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ugZ2tbkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UwxDfsnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kOo9Im06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ra3MEDIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gzXG5zxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yAw6fAKt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_uVHiGDOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_zzecy0BS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NfiehS2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5r77kSOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GIG6mLF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AF8PAOMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ifqhzkuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RSAeeFex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dirE9CGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dMWnAzmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kKjje1XX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oNZvmqF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2I1CUhQQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_a5CZWxyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_hNpVn8li_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_krx5XaDr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oy7IovJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PCyFcNV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_syMWTAw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NaAG5vBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nfv3hqyc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lPE74pv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HaHLoerV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fLnHRTqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iW24JQnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxFG4p17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ip3LD4a6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1aoysT2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bImGvoNJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iEvFWzbG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4cABk9xO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IuRv6Hbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yEj49a02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TW921fw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Apjq2dUz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jDwAeE7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QeNDc5PZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g2U5RBrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gJ1qgYl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mYhWFqWO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nVrw2pNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mdE5YA5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GpNObIvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WNPXIcCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J3JByscg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_beRxF7dV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RBAmDpzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tNj6AD1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cuzcTmY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z5GrWJXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fRzQeG9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OkseMblj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7vtfBDpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DH8VIBF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YLn4plNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hXyN6Gaj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BZrtO6pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P9bkBk1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JjpJYeFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x16ZI3Qw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AVSWdhIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_08RlrCHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Gdxit1aF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PH42jgMa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LYXAGvBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JjwpjJLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_E70Bmtpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BqEwDa7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jaToUkG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sKiXNQCz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FUlsDDdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zt3ObWqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n8CsP33k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HEftZWZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yoCUp7Iz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xEct8SIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PPjM5siT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kmvgeuds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0YZMhqjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bHnLdsNb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gn13ruHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XtltbfWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fCPhlmSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8GGn0NFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x7Y7cCby_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_9hYZ9lMZ;
  SignalPhasor sPhasor_dYGKvw6g;
  SignalLine sLine_bMo5ooP2;
  SignalRPole sRPole_Ysp2A9CM;
  SignalRPole sRPole_s7MF3JSI;
  SignalTabhead sTabhead_LKipUpMb;
  SignalTabread sTabread_zLpWGFSR;
  SignalTabread sTabread_eYXQcAZU;
  SignalLine sLine_ZC8PsSy1;
  SignalTabhead sTabhead_HAjrWnwX;
  SignalTabread sTabread_GgDpiDkR;
  SignalTabread sTabread_lGGye0c8;
  SignalLine sLine_whK7rgl3;
  SignalTabwrite sTabwrite_GVu0bICL;
  SignalTabwrite sTabwrite_7q80D7mH;
  ControlVar cVar_rU8MfEc9;
  ControlVar cVar_EnCoqboz;
  ControlVar cVar_yCa3tXci;
  ControlVar cVar_ys6rWo1R;
  ControlBinop cBinop_5KlwtKZl;
  ControlBinop cBinop_wQFipoqg;
  ControlVar cVar_ha7O3lRU;
  ControlBinop cBinop_9Dv8bBOV;
  ControlBinop cBinop_Kb1vaquR;
  SignalVarf sVarf_j3MCq2M3;
  SignalVarf sVarf_bZ7Zsuen;
  SignalVarf sVarf_M7A7Rc4B;
  ControlVar cVar_7TCtUYML;
  ControlBinop cBinop_nMwliOgp;
  ControlBinop cBinop_1CrHTPIe;
  SignalVarf sVarf_VNs1j8yc;
  SignalVarf sVarf_5anhbECd;
  SignalVarf sVarf_u24ESYTh;
  ControlBinop cBinop_LpVgBEdl;
  ControlBinop cBinop_6S4959bw;
  ControlBinop cBinop_358Eaeiv;
  ControlBinop cBinop_szW1STas;
  ControlBinop cBinop_EwJ4C0EV;
  ControlBinop cBinop_A6xB2oqf;
  ControlBinop cBinop_56EBWIWc;
  ControlBinop cBinop_HMXzBRDF;
  ControlBinop cBinop_5TVBu2L1;
  ControlBinop cBinop_ugZ2tbkk;
  ControlDelay cDelay_ra3MEDIS;
  ControlDelay cDelay_gzXG5zxe;
  ControlBinop cBinop_uVHiGDOn;
  HvTable hTable_zzecy0BS;
  ControlBinop cBinop_5r77kSOx;
  ControlDelay cDelay_kKjje1XX;
  ControlDelay cDelay_oNZvmqF8;
  ControlBinop cBinop_a5CZWxyP;
  HvTable hTable_hNpVn8li;
  ControlBinop cBinop_oy7IovJu;
  ControlVar cVar_lPE74pv7;
  ControlBinop cBinop_iW24JQnq;
  ControlBinop cBinop_qxFG4p17;
  SignalVarf sVarf_HRC1pyUC;
  ControlBinop cBinop_1aoysT2e;
  ControlBinop cBinop_bImGvoNJ;
  ControlBinop cBinop_iEvFWzbG;
  SignalVarf sVarf_WjfrG7x1;
  ControlVar cVar_4cABk9xO;
  ControlBinop cBinop_TW921fw7;
  ControlBinop cBinop_Apjq2dUz;
  SignalVarf sVarf_Dc5f07bK;
  ControlBinop cBinop_QeNDc5PZ;
  ControlBinop cBinop_g2U5RBrJ;
  ControlBinop cBinop_gJ1qgYl3;
  SignalVarf sVarf_75SwsPQp;
  ControlBinop cBinop_WNPXIcCl;
  ControlBinop cBinop_J3JByscg;
  ControlBinop cBinop_beRxF7dV;
  ControlBinop cBinop_RBAmDpzb;
  ControlBinop cBinop_tNj6AD1G;
  ControlBinop cBinop_Z5GrWJXF;
  ControlBinop cBinop_fRzQeG9R;
  ControlSlice cSlice_7vtfBDpN;
  ControlVar cVar_DH8VIBF6;
  ControlSlice cSlice_BZrtO6pk;
  ControlVar cVar_P9bkBk1M;
  ControlSlice cSlice_AVSWdhIM;
  ControlVar cVar_08RlrCHh;
  ControlSlice cSlice_LYXAGvBl;
  ControlVar cVar_JjwpjJLA;
  ControlBinop cBinop_HEftZWZV;
  ControlBinop cBinop_yoCUp7Iz;
  ControlBinop cBinop_xEct8SIB;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
